import traceback

from cpl_core.configuration import ConfigurationModelABC
from cpl_core.console import Console
from cpl_query.extension import List

from bot_core.configuration.server_settings import ServerSettings


class BotSettings(ConfigurationModelABC):
    def __init__(self):
        ConfigurationModelABC.__init__(self)

        self._servers: List[ServerSettings] = List(ServerSettings)
        self._technicians: List[int] = List(int)
        self._wait_for_restart = 2
        self._wait_for_shutdown = 2
        self._cache_max_messages = 1000

    @property
    def servers(self) -> List[ServerSettings]:
        return self._servers

    @property
    def technicians(self) -> List[int]:
        return self._technicians

    @property
    def wait_for_restart(self) -> int:
        return self._wait_for_restart

    @property
    def wait_for_shutdown(self) -> int:
        return self._wait_for_shutdown

    @property
    def cache_max_messages(self) -> int:
        return self._cache_max_messages

    def from_dict(self, settings: dict):
        try:
            self._technicians = settings["Technicians"]
            self._wait_for_restart = settings["WaitForRestart"]
            self._wait_for_shutdown = settings["WaitForShutdown"]
            settings.pop("Technicians")
            settings.pop("WaitForRestart")
            settings.pop("WaitForShutdown")

            if "CacheMaxMessages" in settings:
                self._cache_max_messages = settings["CacheMaxMessages"]
                settings.pop("CacheMaxMessages")

            servers = List(ServerSettings)
            for s in settings:
                st = ServerSettings()
                settings[s]["Id"] = s
                st.from_dict(settings[s])
                servers.append(st)
            self._servers = servers
        except Exception as e:
            Console.error(f"[ ERROR ] [ {__name__} ]: Reading error in {type(self).__name__} settings")
            Console.error(f"[ EXCEPTION ] [ {__name__} ]: {e} -> {traceback.format_exc()}")
