from abc import ABC, abstractmethod
from typing import Optional

from cpl_query.extension import List

from bot_data.model.user_joined_game_server import UserJoinedGameServer


class UserJoinedGameServerRepositoryABC(ABC):
    @abstractmethod
    def __init__(self):
        pass

    @abstractmethod
    def get_user_joined_game_servers(self) -> List[UserJoinedGameServer]:
        pass

    @abstractmethod
    def get_user_joined_game_server_by_id(self, id: int) -> UserJoinedGameServer:
        pass

    @abstractmethod
    def get_user_joined_game_servers_by_user_id(self, user_id: int) -> List[UserJoinedGameServer]:
        pass

    @abstractmethod
    def get_active_user_joined_game_server_by_user_id(self, user_id: int) -> UserJoinedGameServer:
        pass

    @abstractmethod
    def find_active_user_joined_game_server_by_user_id(self, user_id: int) -> Optional[UserJoinedGameServer]:
        pass

    @abstractmethod
    def find_active_user_joined_game_servers_by_user_id(self, user_id: int) -> List[Optional[UserJoinedGameServer]]:
        pass

    @abstractmethod
    def add_user_joined_game_server(self, user_joined_game_server: UserJoinedGameServer):
        pass

    @abstractmethod
    def update_user_joined_game_server(self, user_joined_game_server: UserJoinedGameServer):
        pass

    @abstractmethod
    def delete_user_joined_game_server(self, user_joined_game_server: UserJoinedGameServer):
        pass

    @abstractmethod
    def delete_user_joined_game_server_by_user_id(self, user_id: int):
        pass
