from cpl_core.dependency_injection import ServiceProviderABC
from cpl_query.extension import List

from bot_data.abc.history_table_abc import HistoryTableABC


class UserHistory(HistoryTableABC):
    def __init__(
        self,
        dc_id: int,
        xp: int,
        server: int,
        deleted: bool,
        date_from: str,
        date_to: str,
        id=0,
    ):
        HistoryTableABC.__init__(self)

        self._user_id = id
        self._discord_id = dc_id
        self._xp = xp
        self._server = server

        self._deleted = deleted
        self._date_from = date_from
        self._date_to = date_to

    @property
    def id(self) -> int:
        return self._user_id

    @property
    def discord_id(self) -> int:
        return self._discord_id

    @property
    def xp(self) -> int:
        return self._xp

    @property
    def server(self) -> int:
        return self._server

    @property
    @ServiceProviderABC.inject
    def left_server(
        self,
        services: ServiceProviderABC,
    ) -> bool:
        from bot_data.abc.user_joined_server_repository_abc import UserJoinedServerRepositoryABC

        ujs: UserJoinedServerRepositoryABC = services.get_service(UserJoinedServerRepositoryABC)
        return ujs.find_active_user_joined_server_by_user_id(self.id) is None

    @property
    @ServiceProviderABC.inject
    def game_idents(
        self,
        services: ServiceProviderABC,
    ) -> List["UserGameIdent"]:
        from bot_data.abc.user_game_ident_repository_abc import UserGameIdentRepositoryABC

        game_idents_repo: UserGameIdentRepositoryABC = services.get_service(UserGameIdentRepositoryABC)
        return game_idents_repo.get_user_game_idents_by_user_id(self.id)
