from cpl_query.extension import List

from bot_data.model.user import User
from bot_graphql.abc.filter_abc import FilterABC


class AchievementFilter(FilterABC):
    def __init__(self):
        FilterABC.__init__(self)

        self._id = None
        self._name = None
        self._attribute = None
        self._operator = None
        self._value = None
        self._server = None

    def from_dict(self, values: dict):
        if "id" in values:
            self._id = int(values["id"])

        if "name" in values:
            self._name = values["name"]

        if "attribute" in values:
            self._attribute = values["attribute"]

        if "operator" in values:
            self._operator = values["operator"]

        if "value" in values:
            self._value = values["value"]

        if "server" in values:
            from bot_graphql.filter.server_filter import ServerFilter

            self._server: ServerFilter = self._services.get_service(ServerFilter)
            self._server.from_dict(values["server"])

    def filter(self, query: List[User]) -> List[User]:
        if self._id is not None:
            query = query.where(lambda x: x.id == self._id)

        if self._name is not None:
            query = query.where(lambda x: x.name == self._name)

        if self._attribute is not None:
            query = query.where(lambda x: x.attribute == self._attribute)

        if self._operator is not None:
            query = query.where(lambda x: x.operator == self._operator)

        if self._value is not None:
            query = query.where(lambda x: x.value == self._value)

        if self._server is not None:
            servers = self._server.filter(query.select(lambda x: x.server)).select(lambda x: x.id)
            query = query.where(lambda x: x.server.id in servers)

        return query
