import traceback

from cpl_core.configuration.configuration_model_abc import ConfigurationModelABC
from cpl_core.console import Console
from cpl_query.extension import List

from modules.boot_log.configuration.boot_log_server_settings import (
    BootLogServerSettings,
)


class BootLogSettings(ConfigurationModelABC):
    def __init__(self):
        ConfigurationModelABC.__init__(self)

        self._servers: List[BootLogServerSettings] = List()

    @property
    def servers(self) -> List[BootLogServerSettings]:
        return self._servers

    def from_dict(self, settings: dict):
        try:
            servers = List(BootLogServerSettings)
            for s in settings:
                st = BootLogServerSettings()
                settings[s]["Id"] = s
                st.from_dict(settings[s])
                servers.append(st)
            self._servers = servers
        except Exception as e:
            Console.error(f"[ ERROR ] [ {__name__} ]: Reading error in {type(self).__name__} settings")
            Console.error(f"[ EXCEPTION ] [ {__name__} ]: {e} -> {traceback.format_exc()}")
