export class Queries {

  static guildsQuery = `
    query GuildsQuery($id: ID) {
      guilds(filter: {id: $id}) {
        id
        name

        channels {
          id
          name
          type
        }
        roles {
          id
          name
        }
        emojis {
          id
          name
          url
        }
      }
    }
  `;

  static serversQuery = `
    query ServerInfo($filter: ServerFilter, $page: Page, $sort: Sort) {
      serverCount
      servers(filter: $filter, page: $page, sort: $sort) {
        id
        name
        iconURL
        userCount
        clients{
          id
          discordId
          name
          sentMessageCount
          receivedMessageCount
          deletedMessageCount
          receivedCommandCount
          movedUsersCount
        }
      }
    }
  `;

  static levelQuery = `
    query LevelsList($serverId: ID, $filter: LevelFilter, $page: Page, $sort: Sort) {
      servers(filter: {id: $serverId}) {
        levelCount
        levels(filter: $filter, page: $page, sort: $sort) {
          id
          name
          color
          minXp
          permissions
          server {
            id
            name
          }
          createdAt
          modifiedAt
        }
      }
    }
  `;

  static levelWithHistoryQuery = `
    query LevelHistory($serverId: ID, $id: ID) {
      servers(filter: {id: $serverId}) {
        levelCount
        levels(filter: {id: $id}) {
          id

          history {
            id
            name
            color
            minXp
            permissions
            server
            deleted
            dateFrom
            dateTo
          }
        }
      }
    }
  `;

  static usersQuery = `
    query UsersList($serverId: ID, $filter: UserFilter, $page: Page, $sort: Sort) {
      servers(filter: {id: $serverId}) {
        userCount
        users(filter: $filter, page: $page, sort: $sort) {
          id
          discordId
          name
          xp
          ontime
          level {
            id
            name
          }
          leftServer

          createdAt
          modifiedAt
        }
      }
    }
  `;

  static userProfile = `
    query UserProfile($serverId: ID, $userId: ID, $page: Page, $sort: Sort) {
      servers(filter: {id: $serverId}) {
        userCount
        users(filter: {id: $userId}, page: $page, sort: $sort) {
          id
          discordId
          name
          xp
          ontime
          level {
            id
            name
          }
          leftServer
          server {
            id
            name
          }

          joinedServerCount
          joinedServers {
            id
            joinedOn
            leavedOn
          }

          joinedVoiceChannelCount
          joinedVoiceChannels {
            id
            channelId
            channelName
            time
            joinedOn
            leavedOn
          }

          userJoinedGameServerCount
          userJoinedGameServers {
            id
            gameServer
            time
            joinedOn
            leavedOn
          }
        }
      }
    }
  `;

  static userQueryWithHistory = `
    query UsersWithHistory($serverId: ID, $id: ID) {
      servers(filter: {id: $serverId}) {
        userCount
        users(filter: {id: $id}) {
          id

          history {
            id
            discordId
            xp
            server
            deleted
            dateFrom
            dateTo
          }
        }
      }
    }
  `;

  static autoRolesQuery = `
    query AutoRoleQuery($serverId: ID, $filter: AutoRoleFilter, $page: Page, $sort: Sort) {
      servers(filter: {id: $serverId}) {
        autoRoleCount
        autoRoles(filter: $filter, page: $page, sort: $sort) {
          id
          channelId
          channelName
          messageId
          autoRoleRuleCount

          server {
            id
          }

          createdAt
          modifiedAt
        }
      }
    }
  `;

  static autoRolesWithHistoryQuery = `
    query AutoRoleWithHistoryQuery($serverId: ID, $id: ID) {
      servers(filter: {id: $serverId}) {
        autoRoleCount
        autoRoles(filter: {id: $id}) {
          id

          history {
            id
            channelId
            messageId
            server
            deleted
            dateFrom
            dateTo
          }
        }
      }
    }
  `;

  static autoRoleRulesQuery = `
    query AutoRoleRuleQuery($serverId: ID, $autoRoleId: ID, $filter: AutoRoleRuleFilter, $page: Page, $sort: Sort) {
      servers(filter: {id: $serverId}) {
        autoRoles(filter: {id: $autoRoleId}) {
          autoRoleRuleCount
          autoRoleRules(filter: $filter, page: $page, sort: $sort) {
            id
            emojiName
            roleId
            roleName

            autoRole {
              id
            }

            createdAt
            modifiedAt
          }
        }
      }
    }
  `;

  static autoRoleRulesHistoryQuery = `
    query AutoRoleRuleHistoryQuery($serverId: ID, $autoRoleId: ID, $id: ID) {
      servers(filter: {id: $serverId}) {
        autoRoles(filter: {id: $autoRoleId}) {
          autoRoleRuleCount
          autoRoleRules(filter: {id: $id}) {
            id

            history {
              id
              emojiName
              roleId
              autoRole
              deleted
              dateFrom
              dateTo
            }
          }
        }
      }
    }
  `;
}
